package Weed::Field::SFComplex;
use strict;
use warnings;

use Weed 'SFComplex : X3DField { }';

use Math::Complex;

1;
__END__
